@@ -107,6 +107,9 @@
 
 #define VEND_CREATIVE         0x041e
 #define PROD_LIVE_VISTA_IM    0x4052
+#define PROD_LIVE_VISTA_VF0330     0x405f
+#define PROD_LIVE_VISTA_VF0350     0x4060	/* Creative Live Cam */
+#define PROD_LIVE_VISTA_VF0420     0x4064
 
 /* --------------------------------- */
 /*      DEVICE IMPLEMENTATIONS       */
